==> collab_learning_extension-0.2.4.tar.gz: collab_learning_extension-0.2.4/src/widget/component/cell/type/textCell/student/TextCellStudentComponent.tsx <==
import React, { useContext } from 'react';
import { DocModelContext, IDocModelContext } from '../../../../../context';
import { useSelector } from 'react-redux';
import {
  RootState,
  selectCell,
  selectField,
  selectStudentSolutionField
} from '../../../../../../state';
import { ITextResponseAnswer } from 'react-quiz-ui';
import {
  IMarkdownField,
  ITextCell,
  ITextSolution
} from '../../../../../../types';
import { TextResponseStudent } from '../../../../../../ui';

type TextCellStudentComponentProps = {
  cellId: string;
};
const TextCellStudentComponent = (props: TextCellStudentComponentProps) => {
  const { addStudentSolutionField, changeField } = useContext(
    DocModelContext
  ) as IDocModelContext;
  const username = useSelector(
    (state: RootState) => state.user.identity?.username
  ) as string;
  const studentSolution = useSelector((state: RootState) =>
    selectStudentSolutionField(state, props.cellId, username)
  ) as ITextSolution;
  const showSolution = useSelector(
    (state: RootState) => selectCell(state, props.cellId).metadata.showSolution
  );
  const solutionField = useSelector((state: RootState) =>
    selectField(
      state,
      (selectCell(state, props.cellId) as ITextCell).solutionId
    )
  ) as IMarkdownField;
  const setStudentSolution = (answer: ITextResponseAnswer) =>
    changeField({ ...studentSolution, src: answer.answer.src });

  if (studentSolution === undefined) {
    addStudentSolutionField(props.cellId, 'text-solution');
    return <></>;
  }
  return (
    <>
      <TextResponseStudent
        answer={studentSolution.src}
        onAnswerChanges={setStudentSolution}
        options={{
          showSolution: showSolution,
          submitted: studentSolution.submitted
        }}
        setSubmit={(submitted: boolean) =>
          changeField({ ...studentSolution, submitted })
        }
        comment={studentSolution.comment}
        solution={solutionField.src}
      ></TextResponseStudent>
    </>
  );
};

export default TextCellStudentComponent;

==> collab_learning_extension-0.2.7.tar.gz: collab_learning_extension-0.2.7/src/widget/component/cell/type/textCell/student/TextCellStudentComponent.tsx <==
import React, { useContext } from 'react';
import { DocModelContext, IDocModelContext } from '../../../../../context';
import { useSelector } from 'react-redux';
import {
  RootState,
  selectCell,
  selectField,
  selectStudentSolutionField
} from '../../../../../../state';
import { ITextResponseAnswer } from 'react-quiz-ui';
import {
  IMarkdownField,
  ITextCell,
  ITextSolution
} from '../../../../../../types';
import { TextResponseStudent } from '../../../../../../ui';

type TextCellStudentComponentProps = {
  cellId: string;
};
const TextCellStudentComponent = (props: TextCellStudentComponentProps) => {
  const { addStudentSolutionField, changeField } = useContext(
    DocModelContext
  ) as IDocModelContext;
  const username = useSelector(
    (state: RootState) => state.user.identity?.username
  ) as string;
  const studentSolution = useSelector((state: RootState) =>
    selectStudentSolutionField(state, props.cellId, username)
  ) as ITextSolution;
  const showSolution = useSelector(
    (state: RootState) => selectCell(state, props.cellId).metadata.showSolution
  );
  const solutionField = useSelector((state: RootState) =>
    selectField(
      state,
      (selectCell(state, props.cellId) as ITextCell).solutionId
    )
  ) as IMarkdownField;
  const setStudentSolution = (answer: ITextResponseAnswer) =>
    changeField({ ...studentSolution, src: answer.answer.src });

  if (studentSolution === undefined) {
    addStudentSolutionField(props.cellId, 'text-solution');
    return <></>;
  }
  return (
    <>
      <TextResponseStudent
        answer={studentSolution.src}
        onAnswerChanges={answer => {
          if (answer.answer.src !== studentSolution.src) {
            setStudentSolution(answer);
          }
        }}
        options={{
          showSolution: showSolution,
          submitted: studentSolution.submitted
        }}
        setSubmit={(submitted: boolean) =>
          changeField({ ...studentSolution, submitted })
        }
        comment={studentSolution.comment}
        solution={solutionField.src}
      ></TextResponseStudent>
    </>
  );
};

export default TextCellStudentComponent;
